@@ -64,6 +64,19 @@ const char *zmq::errno_to_string (int errno_)
     }
 }
 
+void zmq::zmq_abort(const char *errmsg_)
+{
+#if defined ZMQ_HAVE_WINDOWS
+
+    //  Raise STATUS_FATAL_APP_EXIT.
+    ULONG_PTR extra_info [1];
+    extra_info [0] = (ULONG_PTR) errmsg_;
+    RaiseException (0x40000015, EXCEPTION_NONCONTINUABLE, 1, extra_info);
+#else
+    abort ();
+#endif
+}
+
 #ifdef ZMQ_HAVE_WINDOWS
 
 const char *zmq::wsa_error()
